############################################################################################################
# Version: 14 January 2015
# 
# Author: Roel Brienen 
#
# When using these data please cite the original article:
#      R.J.W. Brienen*, O.L. Phillips*, T.R. Feldpausch, E. Gloor, T.R. Baker, J. Lloyd, G. Lopez-Gonzalez et al. 
#      Long-term decline of the Amazon carbon sink
# See: http://dx.doi.org/10.5521/ForestPlots.net/2014_4
#
############################################################################################################

rm(list=ls(all=TRUE))

#Packages required:  
library(doBy);library(MASS);  library(plyr);library(boot);library(zoo); library(gamm4); library(lme4) ; library(car);library(pbkrtest); 
library(cwhmisc) ; library(lattice); library(reshape); library(Rfit)

# set your own working directory
setwd("xxxx")

############################################################################################################
# DATASETS REQUIRED:
############################################################################################################

# These are the plot-by_plot census-by-census data; see documentation for definition of variables 
dataSel_wss=read.csv(file="data_by_cens.csv")

# These contain longitudinal data on biomass dynamics for each analysis unit 1980-2011.5 in time steps of 0.1 year
# Note that some plots were merged for analysis purposes: see ED.
all_long=read.csv(file="data_long_1980.csv")

# Variable names used for plotting fig 1 ########################################################################################
var1="AGBnetchange"
var2="AGBGain_tot"
var4="AGBMor_tot" 
var5="qua_lo_net_wt"
var6="qua_hi_net_wt"
var9="qua_lo_gaintot_wt"      
var10= "qua_hi_gaintot_wt"  
var11= "qua_lo_mortot_wt"  	
var12= "qua_hi_mortot_wt"

# Setting axis limits and legends
y_axis_1=c(-2,3)
y_axis_2=c(2.5,7)
y_axis_3=c(2.5,7)
labely=expression("a. Net biomass change")
labely2=expression("b. Productivity")
labely3=expression("c. Biomass mortality")
Ly1=expression("Biomass change (Mg ha"^"-1"*"yr"^"-1"*")")
Ly2=expression("Productivity (Mg ha"^"-1"*"yr"^"-1"*")")
Ly3=expression("Mortality (Mg ha"^"-1"*"yr"^"-1"*")")

all_long$var1    = all_long[,c(var1)]    # for net change
all_long$var2    = all_long[,c(var2)]    # for gains
all_long$var4    = all_long[,c(var4)]    # for mortality

r=100  # Number of bootstraps
all_long$weight= all_long$PlotArea^0.5# add weights to dataset
Basin_long_pl_wss = ddply(all_long, .(year), 
                      function(x) data.frame(
                        AGBnetchange      = weighted.mean(x$var1, (x$weight), na.rm=TRUE),   # plot area weighted 
                        qua_lo_net_wt    	= quantile(boot(x$var1, function(var1, d) mean(x$var1[d], na.rm=TRUE), weight=(x$weight), sim="balanced", R=r)$t, c(0.025), na.rm=TRUE),# bootstrapping CI (2.5% -97.5%) around the mean
                        qua_hi_net_wt		  = quantile(boot(x$var1, function(var1, d) mean(x$var1[d], na.rm=TRUE), weight=(x$weight), sim="balanced", R=r)$t, c(0.975), na.rm=TRUE),
                        
                        AGBGain_tot         = weighted.mean(x$var2, (x$weight),na.rm=TRUE),
                        qua_lo_gaintot_wt   = quantile(boot(x$var2, function(var2, d) mean(x$var2[d], na.rm=TRUE), weight=(x$weight), sim="balanced", R=r)$t, c(0.025), na.rm=TRUE),# bootstrapping CI (2.5% -97.5%) around the mean
                        qua_hi_gaintot_wt		= quantile(boot(x$var2, function(var2, d) mean(x$var2[d], na.rm=TRUE), weight=(x$weight), sim="balanced", R=r)$t, c(0.975), na.rm=TRUE),     
                        
                        AGBMor_tot  	      = weighted.mean(x$var4, (x$weight),na.rm=TRUE),
                        qua_lo_mortot_wt    = quantile(boot(x$var4, function(var4, d) mean(x$var4[d], na.rm=TRUE), weight=(x$weight), sim="balanced", R=r)$t, c(0.025), na.rm=TRUE),# bootstrapping CI (2.5% -97.5%) around the mean
                        qua_hi_mortot_wt		= quantile(boot(x$var4, function(var4, d) mean(x$var4[d], na.rm=TRUE), weight=(x$weight), sim="balanced", R=r)$t, c(0.975), na.rm=TRUE),
                        Nplots    			      = sum(x$N_units, na.rm=TRUE),
                        meaninterv_cens_length 	= mean(x$int_c_length, na.rm=TRUE),
                        meanplotarea			      = mean(x$PlotArea, na.rm=TRUE)))

# Smooth all lines 
Basin_long_pl_wss[,2:10]  =rollmean(Basin_long_pl_wss[,2:10] , 5, fill="extend")

# Remove interval dates before start and end of analysis period, the cut-off date for analysis figure 1. 
interval_start= 1983 ; interval_end= 2011.5
JJ = which(dataSel_wss$int_fin< interval_start)
dataSel_wss= dataSel_wss[-JJ,]
LL=which(dataSel_wss$mid_int_date>interval_end)
dataSel_wss=dataSel_wss[-LL,]
II = which(dataSel_wss$int_ini<interval_start)
dataSel_wss[II,"int_ini"]=interval_start
KK = which(dataSel_wss$int_fin>interval_end)
dataSel_wss[KK,"int_fin"]=interval_end
dataSel_wss$int_c_length=dataSel_wss$int_fin-dataSel_wss$int_ini

# Add teller for the number of censuses
for (i in 1: length(levels(dataSel_wss$PlotViewName))) { 
  I=which(dataSel_wss$PlotViewName==levels(dataSel_wss$PlotViewName) [i])
  if(length(I)>0) {
    dataSel_wss[I,"tot_monitor_length"]= max(dataSel_wss[I,"int_fin"])-min(dataSel_wss[I,"int_ini"])
  }
}

# Adding weight to the data for the regression models used 
dataSel_wss$weight = ((dataSel_wss$int_c_length/dataSel_wss$tot_monitor_length)*(dataSel_wss$plot_area)^0.5)# 

##### GAMM model used as "best estimate of overall trends" with plot as random effect for intercept. Slopes are fixed effects.  
wtAGBnetchange_gamm =gamm4(dataSel_wss[,c(var1)]~ s(mid_int_date), random=~(1|PlotViewName), data=dataSel_wss, weight=dataSel_wss$weight, na.action=na.omit)
wtAGBGain_tot_gamm=gamm4(dataSel_wss[,c(var2)]~ s(mid_int_date), random=~(1|PlotViewName), data=dataSel_wss, weight=dataSel_wss$weight, na.action=na.omit)
wtAGBMor_tot_gamm=gamm4(dataSel_wss[,c(var4)] ~s(mid_int_date), random=~(1|PlotViewName), data=dataSel_wss, weight=dataSel_wss$weight, na.action=na.omit)

# Predict lines GAMM model 
mid_int_date=seq(1983, 2011.5, 0.1) 
outp=data.frame(mid_int_date)
predict_netchange=predict(wtAGBnetchange_gamm$gam, outp, type="link", se.fit=T)
predict_gain=predict(wtAGBGain_tot_gamm$gam, outp, type="link", se.fit=T)
predict_mort=predict(wtAGBMor_tot_gamm$gam, outp, type="link", se.fit=T)
gamm_pred= cbind(predict_netchange, predict_gain, predict_mort, outp)
colnames(gamm_pred)=c("netchange_fit", "net_change_err", "gain_fit", "gain_err", "mort_fit", "mort_err", "year")###
mid_date = (interval_start + interval_end)/2

# Estimate linear slopes using lmer with plot as random effect for intercept. Slopes are fixed effects. 
model_netchange<-lmer(dataSel_wss[,c(var1)] ~ dataSel_wss$mid_int_date + (1|PlotViewName), data=dataSel_wss,weights=weight, na.action=na.omit) 
slope_netchange=summary(model_netchange)$coefficients[[2]] ; p_netchange = Anova(model_netchange, test.statistic=c("F")) [[4]]
mean_netchange=mid_date*slope_netchange + summary(model_netchange)$coefficients[[1]]
model_wtAGBGain_tot<-lmer(dataSel_wss[,c(var2)] ~ dataSel_wss$mid_int_date+ (1|PlotViewName), data=dataSel_wss,weights=weight, na.action=na.omit) 
slope_Gain=summary(model_wtAGBGain_tot)$coefficients[[2]] ; p_Gain= Anova(model_wtAGBGain_tot, test.statistic=c("F")) [[4]]
mean_Gain=mid_date*slope_Gain + summary(model_wtAGBGain_tot)$coefficients[[1]]
model_wtAGBMor_tot<-lmer(dataSel_wss[,c(var4)] ~ dataSel_wss$mid_int_date+ (1|PlotViewName), data=dataSel_wss, weights=weight, na.action=na.omit)#, family=poisson(link = "log"))
slope_Mor=summary(model_wtAGBMor_tot)$coefficients[[2]] ; p_Mor= Anova(model_wtAGBMor_tot, test.statistic=c("F")) [[4]]
mean_Mor=mid_date*slope_Mor + summary(model_wtAGBMor_tot)$coefficients[[1]]

# Estimate non-parametric  slopes using Rfit 
model_netchange_NP  = rfit(dataSel_wss[,c(var1)] ~ dataSel_wss$mid_int_date, scores=bentscores1)  # bentscores1= highly right skewed distribution
model_AGBGain_tot_NP= rfit(dataSel_wss[,c(var2)] ~ dataSel_wss$mid_int_date, scores=nscores)      # nscores= light moderate tailed distribution
model_AGBMor_tot_NP = rfit(dataSel_wss[,c(var4)] ~ dataSel_wss$mid_int_date, scores=bentscores3)  # bentscores3= highly left skewed distribution
 
slope_netchange_NP=summary(model_netchange_NP)$coefficients[[2]] ; p_netchange_NP = summary(model_netchange_NP)$coefficients[[8]]
slope_Gain_NP=summary(model_AGBGain_tot_NP)$coefficients[[2]] ; p_Gain_NP= summary(model_AGBGain_tot_NP)$coefficients[[8]]
slope_Mor_NP=summary(model_AGBMor_tot_NP)$coefficients[[2]] ; p_Mor_NP= summary(model_AGBMor_tot_NP)$coefficients[[8]]
    
##############################
quartz("Ms Fig 1") # Plots the figures

plot_sum=summaryBy(N_plots  ~PlotViewName, data=dataSel_wss,FUN= c(mean),na.rm=TRUE)  
N_plots=sum(plot_sum$N_plots.mean, na.rm=T)# Eli is two plots  
  if (var1=="AGBnetchange"){N_plots=N_plots+1} # Eli is two plots 
  
x_axis=c(1983, interval_end)
Basin_long_pl_wss= Basin_long_pl_wss[which(Basin_long_pl_wss$year<interval_end),]
Basin_long_pl_wss$col=  1-0.6*(Basin_long_pl_wss$Nplots/max(Basin_long_pl_wss$Nplots))
Basin_long_pl_wss[which(Basin_long_pl_wss$col<0.5),c("col")] = 0.50

# first panel with net change
par(fig=c(0,1,0.666, 1), omi=c(0.8,0.8,0.5,0.5),mai=c(0,0,0,0))
plot(Basin_long_pl_wss[,c("AGBnetchange")]~Basin_long_pl_wss$year, type="l",xlab="", ylab="",  ylim=y_axis_1, xaxt="n",yaxt="n",
     lwd=0.5, xlim=x_axis, frame =F)

# procedure for setting color of confidence bands which depends on the number of plots included in estimate of the mean. 
for (ii in 1: (length(Basin_long_pl_wss$year))) {
  x1= Basin_long_pl_wss$year[ii]
  x2= Basin_long_pl_wss$year[ii+1]
  y1= Basin_long_pl_wss[,c(var6)][ii]
  y2= Basin_long_pl_wss[,c(var6)][ii+1]
  y3= Basin_long_pl_wss[,c(var5)][ii+1]
  y4= Basin_long_pl_wss[,c(var5)][ii]
  polygon(c(x1, x2, x2, x1), 
          c(y1, y2, y3, y4), col=grey(Basin_long_pl_wss[ii,"col"]), border=grey(Basin_long_pl_wss[ii,"col"]), density=NA)}

# Plot longitudinal mean  
lines(Basin_long_pl_wss[1:100,c("AGBnetchange")]~Basin_long_pl_wss[1:100,c("year")], type="l",col="grey30",  lwd=1.5, lty="dotted")
lines(Basin_long_pl_wss[100:length(Basin_long_pl_wss$year),c("AGBnetchange")]~Basin_long_pl_wss[100:length(Basin_long_pl_wss$year),c("year")], type="l",col="grey30",  lwd=1.5)
abline(h=0, v=0, col = "gray60", lwd=0.7) ; abline(v=1980, col = "gray60", lwd=0.7);   abline(v=1990, col = "gray60", lwd=0.7)
abline(v=2000, col = "gray60", lwd=0.7) ; abline(v=2010, col = "gray60", lwd=0.7)

# Plot gamm model estimates of time trends
lines(gamm_pred$netchange_fit~ gamm_pred$year, col="red", lwd=1)
lines(gamm_pred$netchange_fit+gamm_pred$net_change_err~ gamm_pred$year, lty="dotdash", col="red", lwd=1)
lines(gamm_pred$netchange_fit-gamm_pred$net_change_err~ gamm_pred$year, lty="dotdash", col="red", lwd=1)

axis(2, cex.axis=0.7) ; mtext(Ly1, side=2,line=2.5, cex=0.7)
text(interval_start-1,y_axis_1[[2]]-0.05*(y_axis_1[[2]]-y_axis_1[[1]]),pos=4 , paste(labely))
text(interval_end-3,y_axis_1[[2]]-0.05*(y_axis_1[[2]]-y_axis_1[[1]]),pos=2, paste("Number of plots=",N_plots), cex=0.7)

text(interval_end-3,y_axis_1[[2]]-0.15*(y_axis_1[[2]]-y_axis_1[[1]]),pos=2, bquote("Slope=" ~.(round(slope_netchange,3)) ~ "Mg" ~ ha^-1~ yr^-2), cex=0.7)

if(p_netchange<0.001) {text(interval_end-3,y_axis_1[[2]]-0.25*(y_axis_1[[2]]-y_axis_1[[1]]),pos=2, bquote("p<0.001"), cex=0.7)} 
if(p_netchange>0.001) {text(interval_end-3,y_axis_1[[2]]-0.25*(y_axis_1[[2]]-y_axis_1[[1]]),pos=2, bquote("p=" ~.(round(p_netchange,3))), cex=0.7)}

## Second panel with gains
par(new=T)
par(fig=c(0,1, 0.333,0.666), omi=c(0.8,0.8,0.5,0.5),mai=c(0,0,0,0))
plot(Basin_long_pl_wss[,c( "AGBGain_tot")]~Basin_long_pl_wss$year, xlab="", ylab="", type="l",xaxt="n", yaxt="n", xlim=x_axis, ylim=y_axis_2, 
     lwd=1.5, frame =F) 
for (ii in 1: (length(Basin_long_pl_wss$year))) {
  x1= Basin_long_pl_wss$year[ii]
  x2= Basin_long_pl_wss$year[ii+1]
  y1= Basin_long_pl_wss[,c(var10)][ii]
  y2= Basin_long_pl_wss[,c(var10)][ii+1]
  y3= Basin_long_pl_wss[,c(var9)][ii+1]
  y4= Basin_long_pl_wss[,c(var9)][ii]
  polygon(c(x1, x2, x2, x1), 
          c(y1, y2, y3, y4), col=grey(Basin_long_pl_wss[ii,"col"]), border=grey(Basin_long_pl_wss[ii,"col"]), density=NA)}
lines(Basin_long_pl_wss[1:100,c( "AGBGain_tot")]~Basin_long_pl_wss[1:100,c("year")], type="l",col="grey30",  lwd=1.5, lty="dotted")
lines(Basin_long_pl_wss[100:length(Basin_long_pl_wss$year),c( "AGBGain_tot")]~Basin_long_pl_wss[100:length(Basin_long_pl_wss$year),c("year")], type="l",col="grey30",  lwd=1.5)

abline(h=0, v=0, col = "gray60", lwd=0.7) ; abline(v=1980, col = "gray60", lwd=0.7);   abline(v=1990, col = "gray60", lwd=0.7)
abline(v=2000, col = "gray60", lwd=0.7)   ; abline(v=2010, col = "gray60", lwd=0.7) 

lines(gamm_pred$gain_fit~ gamm_pred$year, col="red", lwd=1)
lines(gamm_pred$gain_fit+gamm_pred$gain_err~ gamm_pred$year, lty="dotdash", col="red", lwd=1)
lines(gamm_pred$gain_fit-gamm_pred$gain_err~ gamm_pred$year, lty="dotdash", col="red", lwd=1)

text(interval_start-1,y_axis_2[[2]]-0.05*(y_axis_2[[2]]-y_axis_2[[1]]),pos=4, paste(labely2))
text(interval_end-3,y_axis_2[[2]]-0.05*(y_axis_2[[2]]-y_axis_2[[1]]),pos=2, bquote("Slope=" ~.(round(slope_Gain,3)) ~ "Mg" ~ ha^-1~ yr^-2), cex=0.7)

if(p_Gain<0.001) {text(interval_end-3,y_axis_2[[2]]-0.15*(y_axis_2[[2]]-y_axis_2[[1]]),pos=2, bquote("p<0.001"), cex=0.7)} 
if(p_Gain>0.001) {text(interval_end-3,y_axis_2[[2]]-0.15*(y_axis_2[[2]]-y_axis_2[[1]]),pos=2, bquote("p=" ~.(round(p_Gain,3))), cex=0.7)}
axis(2, cex.axis=0.7) ; mtext(Ly2,side=2,line=2.5, cex=0.7)


## Third panel with mortality	
par(new=T)
par(fig=c(0,1, 0, 0.333), omi=c(0.8,0.8,0.5,0.5),mai=c(0,0,0,0))
plot(Basin_long_pl_wss[,c("AGBMor_tot" )]~Basin_long_pl_wss$year, xlab="", ylab="", type="l", xaxt="n",yaxt="n",  xlim=x_axis,ylim=y_axis_3,
     lwd=1.5, frame =F) #,
for (ii in 1: (length(Basin_long_pl_wss$year))) {
  x1= Basin_long_pl_wss$year[ii]
  x2= Basin_long_pl_wss$year[ii+1]
  y1= Basin_long_pl_wss[,c(var12)][ii]
  y2= Basin_long_pl_wss[,c(var12)][ii+1]
  y3= Basin_long_pl_wss[,c(var11)][ii+1]
  y4= Basin_long_pl_wss[,c(var11)][ii]
  polygon(c(x1, x2, x2, x1), 
          c(y1, y2, y3, y4), col=grey(Basin_long_pl_wss[ii,"col"]), border=grey(Basin_long_pl_wss[ii,"col"]), density=NA)}

lines(Basin_long_pl_wss[1:100,c("AGBMor_tot" )]~Basin_long_pl_wss[1:100,c("year")], type="l",col="grey30",  lwd=1.5, lty="dotted")
lines(Basin_long_pl_wss[100:length(Basin_long_pl_wss$year),c("AGBMor_tot" )]~Basin_long_pl_wss[100:length(Basin_long_pl_wss$year),c("year")], type="l",col="grey30",  lwd=1.5)

abline(h=0, v=0, col = "gray60", lwd=0.7) ; abline(v=1980, col = "gray60", lwd=0.7);   abline(v=1990, col = "gray60", lwd=0.7)
abline(v=2000, col = "gray60", lwd=0.7) ; abline(v=2010, col = "gray60", lwd=0.7)

lines(gamm_pred$mort_fit~ gamm_pred$year, col="red", lwd=1)
lines(gamm_pred$mort_fit+gamm_pred$mort_err~ gamm_pred$year, lty="dotdash", col="red", lwd=1)
lines(gamm_pred$mort_fit-gamm_pred$mort_err~ gamm_pred$year, lty="dotdash", col="red", lwd=1)

text(interval_start-1,y_axis_3[[2]]-0.05*(y_axis_3[[2]]-y_axis_3[[1]]),pos=4, paste(labely3))
text(interval_end-3,y_axis_3[[2]]-0.05*(y_axis_3[[2]]-y_axis_3[[1]]),pos=2, bquote("Slope=" ~.(round(slope_Mor,3)) ~ "Mg" ~ ha^-1~ yr^-2), cex=0.7)

if(p_Mor<0.001) {text(interval_end-3,y_axis_3[[2]]-0.15*(y_axis_3[[2]]-y_axis_3[[1]]),pos=2, bquote("p<0.001"), cex=0.7)} 
if(p_Mor>0.001) {text(interval_end-3,y_axis_3[[2]]-0.15*(y_axis_3[[2]]-y_axis_3[[1]]),pos=2, bquote("p=" ~.(round(p_Mor,3))), cex=0.7)}
mtext(expression("year"),side=1,line=2.5, cex=0.7); axis(1, cex.axis=0.7)
axis(2, cex.axis=0.7) ; mtext(Ly3,side=2,line=2.5, cex=0.7)